@@ -35,6 +35,8 @@ ureg.define("euro = [] = EUR = Eur = eur = Euro = Euros = €")
 ureg.define("dollar = [] = USD = Usd = usd = Dollar = Dollars = $")
 ureg.define("capita = []")
 ureg.define("dimensionless = []")
+ureg.define('fraction = [] = frac')
+ureg.define('percent = 1e-2 frac = pct')
 
 # Named tuples
 Issue = namedtuple("Issue",
